.. currentmodule:: wcosmo

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:


.. autosummary::
   :toctree: api
   :template: custom-module-template.rst
   :caption: API
   :recursive:

   wcosmo
   utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
